@@ -8,7 +8,7 @@ grtslin <- function (shapefilename=NULL, linframe, samplesize=100, SiteBegin=1,
 # Programmers: Tony Olsen, Tom Kincaid, Don Stevens, Christian Platt,
 #   			Denis White, Richard Remington
 # Date: May 19, 2004
-# Last Revised: January 27, 2015
+# Last Revised: August 18, 2016
 # Description:      
 #   This function select a GRTS sample of a linear resource.  The function uses
 #   hierarchical randomization to ensure that the sample will include no more
@@ -46,6 +46,11 @@ grtslin <- function (shapefilename=NULL, linframe, samplesize=100, SiteBegin=1,
 #     cells
 ################################################################################
 
+# Ensure that the processor is little-endian
+
+   if(.Platform$endian == "big") 
+      stop("\nA little-endian processor is required for the grtslin function.")
+
 # Determine the number of levels for hierarchical randomization
 
    temp <- .Call("numLevels", shapefilename, samplesize, shift.grid,
