@@ -1,7 +1,17 @@
 ### R code from vignette source 'Finite_Design.Rnw'
 
 ###################################################
-### code chunk number 1: preliminaries
+### code chunk number 1: processor
+###################################################
+# Ensure that the processor is little-endian
+
+if(.Platform$endian == "big") 
+   stop("\nA little-endian processor is required for this vignette.")
+
+
+
+###################################################
+### code chunk number 2: preliminaries
 ###################################################
 # Load the spsurvey package
 library(spsurvey)
@@ -9,7 +19,7 @@ library(spsurvey)
 
 
 ###################################################
-### code chunk number 2: createshape
+### code chunk number 3: createshape
 ###################################################
 # Load the sp object in the data directory
 data(NE_lakes)
@@ -20,7 +30,7 @@ sp2shape(sp.obj=NE_lakes, shpfilename="NE_lakes")
 
 
 ###################################################
-### code chunk number 3: att
+### code chunk number 4: att
 ###################################################
 # Read the attribute table from the shapefile
 att <- read.dbf("NE_lakes")
@@ -28,7 +38,7 @@ att <- read.dbf("NE_lakes")
 
 
 ###################################################
-### code chunk number 4: att
+### code chunk number 5: att
 ###################################################
 # Display the initial six lines in the attribute data frame
 head(att)
@@ -36,7 +46,7 @@ head(att)
 
 
 ###################################################
-### code chunk number 5: att
+### code chunk number 6: att
 ###################################################
 # Display number of lakes cross-classified by strata and multidensity
 # category
@@ -45,7 +55,7 @@ addmargins(table("State"=att$State, "Lake Area Category"=att$Area_Cat))
 
 
 ###################################################
-### code chunk number 6: Equalsites
+### code chunk number 7: Equalsites
 ###################################################
 # Call the set.seed function so that the survey designs can be replicate
 set.seed(4447864)
@@ -53,7 +63,7 @@ set.seed(4447864)
 
 
 ###################################################
-### code chunk number 7: Equalsites
+### code chunk number 8: Equalsites
 ###################################################
 # Create the design list
 Equaldsgn <- list(None=list(panel=c(PanelOne=300), seltype="Equal"))
@@ -61,7 +71,7 @@ Equaldsgn <- list(None=list(panel=c(PanelOne=300), seltype="Equal"))
 
 
 ###################################################
-### code chunk number 8: Equalsites
+### code chunk number 9: Equalsites
 ###################################################
 # Select the sample
 Equalsites <- grts(design=Equaldsgn,
@@ -75,7 +85,7 @@ Equalsites <- grts(design=Equaldsgn,
 
 
 ###################################################
-### code chunk number 9: Equalsites
+### code chunk number 10: Equalsites
 ###################################################
 # Print the initial six lines of the survey design
 head(Equalsites@data)
@@ -83,7 +93,7 @@ head(Equalsites@data)
 
 
 ###################################################
-### code chunk number 10: Equalsites
+### code chunk number 11: Equalsites
 ###################################################
 # Print the survey design summary
 summary(Equalsites)
@@ -91,7 +101,7 @@ summary(Equalsites)
 
 
 ###################################################
-### code chunk number 11: Stratsites
+### code chunk number 12: Stratsites
 ###################################################
 # Create the design list
 Stratdsgn <- list(CT=list(panel=c(PanelOne=125), seltype="Equal"),
@@ -101,7 +111,7 @@ Stratdsgn <- list(CT=list(panel=c(PanelOne=125), seltype="Equal"),
 
 
 ###################################################
-### code chunk number 12: Stratsites
+### code chunk number 13: Stratsites
 ###################################################
 # Select the sample
 Stratsites <- grts(design=Stratdsgn,
@@ -117,7 +127,7 @@ Stratsites <- grts(design=Stratdsgn,
 
 
 ###################################################
-### code chunk number 13: Stratsites
+### code chunk number 14: Stratsites
 ###################################################
 # Print the initial six lines of the survey design
 head(Stratsites@data)
@@ -125,7 +135,7 @@ head(Stratsites@data)
 
 
 ###################################################
-### code chunk number 14: Stratsites
+### code chunk number 15: Stratsites
 ###################################################
 # Print the survey design summary
 summary(Stratsites)
@@ -133,7 +143,7 @@ summary(Stratsites)
 
 
 ###################################################
-### code chunk number 15: Unequalsites
+### code chunk number 16: Unequalsites
 ###################################################
 # Read the shapefile
 shp <- read.shape("NE_lakes")
@@ -141,7 +151,7 @@ shp <- read.shape("NE_lakes")
 
 
 ###################################################
-### code chunk number 16: Unequalsites
+### code chunk number 17: Unequalsites
 ###################################################
 # Create the design list
 Unequaldsgn <- list(None=list(panel=c(PanelOne=300),
@@ -154,7 +164,7 @@ Unequaldsgn <- list(None=list(panel=c(PanelOne=300),
 
 
 ###################################################
-### code chunk number 17: Unequalsites
+### code chunk number 18: Unequalsites
 ###################################################
 # Select the sample
 Unequalsites <- grts(design=Unequaldsgn,
@@ -169,7 +179,7 @@ Unequalsites <- grts(design=Unequaldsgn,
 
 
 ###################################################
-### code chunk number 18: Unequalsites
+### code chunk number 19: Unequalsites
 ###################################################
 # Print the initial six lines of the survey design
 head(Unequalsites@data)
@@ -177,7 +187,7 @@ head(Unequalsites@data)
 
 
 ###################################################
-### code chunk number 19: Unequalsites
+### code chunk number 20: Unequalsites
 ###################################################
 # Print the survey design summary
 summary(Unequalsites)
@@ -185,7 +195,7 @@ summary(Unequalsites)
 
 
 ###################################################
-### code chunk number 20: Panelsites
+### code chunk number 21: Panelsites
 ###################################################
 # Create the design list
 Paneldsgn <- list(None=list(panel=c(Annual=50, Year1=50, Year2=50, Year3=50,
@@ -199,7 +209,7 @@ Paneldsgn <- list(None=list(panel=c(Annual=50, Year1=50, Year2=50, Year3=50,
 
 
 ###################################################
-### code chunk number 21: Panelsites
+### code chunk number 22: Panelsites
 ###################################################
 # Select the sample
 Panelsites <- grts(design=Paneldsgn,
@@ -214,7 +224,7 @@ Panelsites <- grts(design=Paneldsgn,
 
 
 ###################################################
-### code chunk number 22: Panelsites (eval = FALSE)
+### code chunk number 23: Panelsites (eval = FALSE)
 ###################################################
 ## # Print the warning message
 ## warnings()
@@ -222,7 +232,7 @@ Panelsites <- grts(design=Paneldsgn,
 
 
 ###################################################
-### code chunk number 23: Panelsites
+### code chunk number 24: Panelsites
 ###################################################
 # Print the initial six lines of the survey design
 head(Panelsites@data)
@@ -230,7 +240,7 @@ head(Panelsites@data)
 
 
 ###################################################
-### code chunk number 24: Panelsites
+### code chunk number 25: Panelsites
 ###################################################
 # Print the survey design summary
 summary(Panelsites)
